@@ -1,20 +1,20 @@
 import logging
 
 from ._dimensions import apply_model
-from ._get_ids_tree import get_ids_tree
 from ._handle import ImasHandle
 from ._io import get_ids_dataframe
 from ._mapping import IDSMapping
-from ._rebase import rebase_on_ids, rebase_on_time
+from ._merge import merge_data
+from ._rebase import rebase_on_grid, rebase_on_time
 
 logger = logging.getLogger(__name__)
 
 __all__ = [
     'apply_model',
     'get_ids_dataframe',
-    'get_ids_tree',
     'IDSMapping',
     'ImasHandle',
-    'rebase_on_ids',
+    'merge_data',
+    'rebase_on_grid',
     'rebase_on_time',
 ]
